@@ -3,7 +3,7 @@
 #' by ggplot2 to PNG format with a transparent background and to
 #'  set the resolution.
 #' @param  x A file name that does not have a suffix.
-#' @param  dpi The default dpi is 600. 
+#' @param  dpi The default dpi is 600.
 #' You can enhance the dpi value to produce a higher resolution PNG file.
 #' @param  ...  see :\link{ggsave}
 #' @details  You need to install ImageMagick!
@@ -12,11 +12,11 @@
 #' @return You will get a PNG file with the result drawn by ggplot2.
 #' @author  Chai
 #' @export
-ggpng <- function(x,dpi = 600,...){
-  x1 <- paste0(x,'.pdf')
-  x2 <- paste0(x,'.png')
-  ggsave(x1,...)
-  system(paste('magick -density ',dpi,x1,'-quality 90',x2) )
+ggpng <- function(x, dpi = 600, ...) {
+  x1 <- paste0(x, ".pdf")
+  x2 <- paste0(x, ".png")
+  ggsave(x1, ...)
+  system(paste("magick -density ", dpi, x1, "-quality 90", x2))
 }
 
 #' @rdname ggpng
@@ -24,18 +24,18 @@ ggpng <- function(x,dpi = 600,...){
 #' @details  this ggplot2 object will automatically add a theme with a
 #' transparent background.
 #' @export
-ggPNG <- function(x,p,dpi = 600,...){
-  x1 <- paste0(x,'.pdf')
-  x2 <- paste0(x,'.png')
+ggPNG <- function(x, p, dpi = 600, ...) {
+  x1 <- paste0(x, ".pdf")
+  x2 <- paste0(x, ".png")
   p <- p +
     theme(
       plot.background = element_rect(
-        fill = NA,color = NA),
+        fill = NA, color = NA
+      ),
       panel.background = element_rect(
-        fill = NA, color = NA)
+        fill = NA, color = NA
+      )
     )
-  ggsave(x1,...)
-  system(paste('magick -density ',dpi,x1,'-quality 90',x2) )
+  ggsave(x1, ...)
+  system(paste("magick -density ", dpi, x1, "-quality 90", x2))
 }
-
-
